@@ -1,10 +1,12 @@
 # flake8: noqa
 from necessary import necessary
 
-from mmda.predictors.heuristic_predictors.whitespace_predictor import WhitespacePredictor
-from mmda.predictors.heuristic_predictors.dictionary_word_predictor import DictionaryWordPredictor
+with necessary(["tokenizers"], soft=True) as TOKENIZERS_AVAILABLE:
+    if TOKENIZERS_AVAILABLE:
+        from mmda.predictors.heuristic_predictors.whitespace_predictor import WhitespacePredictor
+        from mmda.predictors.heuristic_predictors.dictionary_word_predictor import DictionaryWordPredictor
+        __all__ = ['DictionaryWordPredictor', 'WhitespacePredictor']
 
-__all__ = ['DictionaryWordPredictor', 'WhitespacePredictor']
 
 with necessary('pysbd', soft=True) as PYSBD_AVAILABLE:
     if PYSBD_AVAILABLE:
